@@ -1,12 +1,14 @@
-from .api import GCSPath, PureGCSPath  # noqa
-from .client import BucketEntry, BucketStat  # noqa
 from .api import (  # noqa
-    get_fs_client,
-    use_fs,
     BucketClient,
+    BucketsAccessor,
     ClientBlob,
     ClientBucket,
     ClientError,
+    GCSPath,
+    PureGCSPath,
+    get_fs_client,
+    use_fs,
 )
+from .client import BucketEntry, BucketStat  # noqa
 from .file import BucketClientFS, BucketEntryFS, ClientBlobFS, ClientBucketFS  # noqa
 from .gcs import BucketClientGCS, BucketEntryGCS, ClientBlobGCS, ClientBucketGCS  # noqa
