@@ -3,10 +3,11 @@ from contextlib import suppress
 from io import DEFAULT_BUFFER_SIZE
 from pathlib import Path, PurePath, _Accessor, _PosixFlavour
 from typing import Generator, Iterable, List, Optional, Union
-
+import os
 import smart_open
 from google.api_core import exceptions as gcs_errors
 from google.cloud import storage
+from google.auth.exceptions import DefaultCredentialsError
 
 from .base import PureGCSPath
 from .client import (
@@ -17,7 +18,7 @@ from .client import (
     ClientBucket,
     ClientError,
 )
-from .gcs import BucketClientGCS, has_gcs
+from . import gcs
 from .file import BucketClientFS
 
 __all__ = ("GCSPath",)
@@ -28,7 +29,7 @@ _SUPPORTED_OPEN_MODES = {"r", "rb", "tr", "rt", "w", "wb", "bw", "wt", "tw"}
 _fs_client: Optional[BucketClientFS] = None
 
 
-def use_fs(root: Optional[Union[str, bool]] = None) -> Optional[BucketClientFS]:
+def use_fs(root: Optional[Union[str, Path, bool]] = None) -> Optional[BucketClientFS]:
     """Use a path in the local file-system to store blobs and buckets.
 
     This is useful for development and testing situations, and for embedded
@@ -44,7 +45,7 @@ def use_fs(root: Optional[Union[str, bool]] = None) -> Optional[BucketClientFS]:
         # Look up "data" folder of gcspath package similar to spaCy
         client_root = Path(__file__).parent / "data"
     else:
-        assert isinstance(root, str), f"root is not a known type: {type(root)}"
+        assert isinstance(root, (str, Path)), f"root is not a known type: {type(root)}"
         client_root = Path(root)
     if not client_root.exists():
         client_root.mkdir(parents=True)
@@ -71,10 +72,14 @@ class BucketsAccessor(_Accessor):
         global _fs_client
         if _fs_client is not None:
             return _fs_client
+        assert self._client is not None, "neither GCS or FS clients are enabled"
         return self._client
 
     def __init__(self, **kwargs):
-        self._client = BucketClientGCS()
+        try:
+            self._client = gcs.BucketClientGCS()
+        except DefaultCredentialsError:
+            self._client = None
 
     def get_blob(self, path: "GCSPath") -> Optional[ClientBlob]:
         """Get the blob associated with a path or return None"""
@@ -86,6 +91,14 @@ class BucketsAccessor(_Accessor):
         key_name = str(path.key)
         return bucket.get_blob(key_name)
 
+    def unlink(self, path: "GCSPath"):
+        """Delete a link to a blob in a bucket."""
+        bucket = self.client.get_bucket(path)
+        blob: Optional[ClientBlob] = bucket.get_blob(str(path.key))
+        if blob is None:
+            raise FileNotFoundError(path)
+        return blob.delete()
+
     def stat(self, path: "GCSPath"):
         bucket = self.client.get_bucket(path)
         blob: Optional[ClientBlob] = bucket.get_blob(str(path.key))
@@ -147,6 +160,9 @@ class BucketsAccessor(_Accessor):
         blob: Optional[ClientBlob] = self.get_blob(path)
         return blob.owner if blob is not None else None
 
+    def resolve(self, path: "GCSPath", strict=False):
+        return GCSPath(os.path.abspath(str(path)))
+
     def rename(self, path: "GCSPath", target: "GCSPath"):
         bucket: ClientBucket = self.client.get_bucket(path)
         target_bucket: ClientBucket = self.client.get_bucket(target)
@@ -183,7 +199,8 @@ class BucketsAccessor(_Accessor):
             self.client.rmdir(path)
 
     def mkdir(self, path: "GCSPath", mode) -> None:
-        self.client.create_bucket(path)
+        if not self.client.lookup_bucket(path):
+            self.client.create_bucket(path)
 
 
 class _PathNotSupportedMixin:
@@ -269,14 +286,6 @@ class _PathNotSupportedMixin:
         message = self._NOT_SUPPORTED_MESSAGE.format(method=self.lstat.__qualname__)
         raise NotImplementedError(message)
 
-    def resolve(self, strict=False):
-        """
-        resolve method is unsupported on GCS service
-        GCS don't have this file system action concept
-        """
-        message = self._NOT_SUPPORTED_MESSAGE.format(method=self.resolve.__qualname__)
-        raise NotImplementedError(message)
-
     def symlink_to(self, *args, **kwargs):
         """
         symlink_to method is unsupported on GCS service
@@ -287,14 +296,6 @@ class _PathNotSupportedMixin:
         )
         raise NotImplementedError(message)
 
-    def unlink(self):
-        """
-        unlink method is unsupported on GCS service
-        GCS don't have this file system action concept
-        """
-        message = self._NOT_SUPPORTED_MESSAGE.format(method=self.unlink.__qualname__)
-        raise NotImplementedError(message)
-
 
 _gcs_accessor = BucketsAccessor()
 
@@ -425,6 +426,14 @@ class GCSPath(_PathNotSupportedMixin, Path, PureGCSPath):
             raise FileNotFoundError(str(self))
         return self._accessor.owner(self)
 
+    def resolve(self):
+        """
+        Return a copy of this path. All paths are absolute in buckets, so no
+        transformation is applied.
+        """
+        self._absolute_path_validation()
+        return self._accessor.resolve(self)
+
     def rename(self, target):
         """
         Renames this file or Bucket / key prefix / key to the given target.
@@ -505,11 +514,8 @@ class GCSPath(_PathNotSupportedMixin, Path, PureGCSPath):
         try:
             if self.bucket is None:
                 raise FileNotFoundError("No bucket in {} {}".format(type(self), self))
-            if self.key is not None and not parents:
-                raise FileNotFoundError(
-                    "Only bucket path can be created, got {}".format(self)
-                )
-            if self.bucket.exists():
+            # If the whole path is just the bucket, respect the
+            if self.key is None and not exist_ok and self.bucket.exists():
                 raise FileExistsError("Bucket {} already exists".format(self.bucket))
             return super().mkdir(mode, parents=parents, exist_ok=exist_ok)
         except OSError:
